@@ -1,5 +1,7 @@
+#' @title
 #' DTLZ7 Function (family)
 #'
+#' @description
 #' Builds and returns the multi-objective DTLZ7 test problem. This problem
 #' can be characterized by a disconnected Pareto-optimal front in the search
 #' space. This introduces a new challenge to evolutionary multi-objective
@@ -41,8 +43,8 @@
 #' @return [\code{smoof_multi_objective_function}]
 #' @export
 makeDTLZ7Function = function(dimensions, n.objectives) {
-  assertInt(n.objectives, lower = 2L, na.ok = FALSE)
-  assertInt(dimensions, lower = n.objectives, na.ok = FALSE)
+  assertInt(n.objectives, lower = 2L)
+  assertInt(dimensions, lower = n.objectives)
 
   # Renaming n.objectives here to stick to the notation in the paper
   M = n.objectives
